Learn R Programming

isocubes (version 1.0.0)

isopointsGrob: Create grob representing isometric grid of points

Description

Create grob representing isometric grid of points

Usage

isopointsGrob(
  N = 50,
  size = 5,
  x = 0.5,
  y = 0.5,
  col = "black",
  pch = ".",
  default.units = "mm",
  verbosity = 0,
  ...
)

Value

isometric point grid

Arguments

N

extents

size

dimensions of cube i.e. the length of the vertical edge of the cube. Default: 5mm

x, y

the origin of the isometric coordinate system. If these values are given as vanilla floating point values, they will be interpreted as 'npc' units, otherwise a valid grid unit object must be supplied. By default the origin is the middle of the graphics device i.e. (x, y) = (0.5, 0.5)

col

Stroke colour for outline of cube faces. Default: black. If NA then no outlines will be drawn. If negative, then outline colour will be the same as the face colour.

pch

plotting character. default '.'

default.units

Default unit for size of a cube is 'mm'

verbosity

Verbosity level. Default: 0

...

other values passed to gpar() to set the graphical parameters e.g. lwd and col for the linewidth and colour of the outline stroke for each cube face.

Examples

Run this code
isopointsGrob(pch = '+') |> 
  grid::grid.draw()

Run the code above in your browser using DataLab