The x, y and z axes are drawn in red, green and blue respectively.
isoaxesGrob(
size = 5,
x = 0.5,
y = 0.5,
default.units = "mm",
xyplane = "flat",
handedness = "right",
labels = TRUE,
verbosity = 0,
...
)grid grob object
length of each axis in default.units
the origin of the isometric coordinate system.
If these values are given as vanilla floating point values, they
will be interpreted as 'npc' units, otherwise a valid grid unit
object must be supplied.
By default the origin is the middle of the graphics device
i.e. (x, y) = (0.5, 0.5)
Default unit for size of a cube is 'mm'
How is the xyplane oriented with respect to the unit isometric cube?. "left", "right", "flat" (or "top"). Default: "flat".
How is the z-axis positioned with respect to the xy-plane? I.e. is this a right-handed or left-handed coordinate system? Default: "right"
Include axis labels? Default: TRUE
Verbosity level. Default: 0
other values passed to gpar() to set the graphical
parameters e.g. lwd and col for the linewidth and colour
of the outline stroke for each cube face.
isoaxesGrob() |>
grid::grid.draw()
Run the code above in your browser using DataLab